@@ -223,15 +223,16 @@ class Audiences(object):
     domain = DEFAULT_DOMAIN
     audience_domains = DEFAULT_AUDIENCE_DOMAINS
     default_audience_id_prefix = DEFAULT_AUDIENCE_ID_PREFIX
-    allowed_audience_fields = DEFAULT_ALLOWED_AUDIENCE_FIELDS
     allowed_field_types = DEFAULT_ALLOWED_FIELD_TYPES
 
     def __init__(self,
                  au_domain=None,
-                 force_db_init=False):
+                 force_db_init=False,
+                 allowed_audience_fields=None):
 
         self.au_domain = au_domain or '_global'
         self.queries = self.get_queries(force_db=force_db_init)
+        self.allowed_audience_fields = allowed_audience_fields or {}
 
     def add(self,
             query,
@@ -271,12 +272,12 @@ class Audiences(object):
         parsed_data = self.parse_profile_data(data=data)
         return [query.au_id for query in self.queries if query.run(parsed_data)]
 
-    def parse_profile_data(cls,
+    def parse_profile_data(self,
                            data):
         parsed = {}
 
-        for field_name, specs in cls.allowed_audience_fields.items():
-            if specs['type'] in cls.allowed_field_types:
+        for field_name, specs in self.allowed_audience_fields.items():
+            if specs['type'] in self.allowed_field_types:
                 value = (data.get(specs['propType']) or {}).get(field_name)
                 parsed[field_name] = value
 
@@ -284,8 +285,8 @@ class Audiences(object):
 
 
     @classmethod
-    def parse_query(cls, query):
-        AudienceQuery.parse(raw_data=query, allowed_fields=cls.allowed_audience_fields)
+    def parse_query(cls, query, allowed_audience_fields):
+        AudienceQuery.parse(raw_data=query, allowed_fields=allowed_audience_fields)
 
     @classmethod
     def n_active(cls, au_domain):
@@ -348,14 +349,14 @@ class Audiences(object):
             return None
 
     @classmethod
-    def get_queries_from_db(cls, au_domain):
+    def get_queries_from_db(cls, au_domain, allowed_audience_fields):
 
         data = [a.short_data for a in cls.django_audience_model.objects.filter(active=True, domain=au_domain)]
 
         if not au_domain == '_global':
             data.extend([a.short_data for a in cls.django_audience_model.objects.filter(active=True, domain='_global')])
 
-        audience_queries = [AudienceQuery.from_raw_data(raw_data=d, allowed_fields=cls.allowed_audience_fields) for d in data]
+        audience_queries = [AudienceQuery.from_raw_data(raw_data=d, allowed_fields=allowed_audience_fields) for d in data]
 
         return audience_queries, data
 
@@ -374,17 +375,18 @@ class Audiences(object):
 
     def build_cache(self):
 
-        self._build_cache(au_domain=self.au_domain)
+        self._build_cache(au_domain=self.au_domain, allowed_audience_fields=self.allowed_audience_fields)
 
     @classmethod
-    def _build_cache(cls, au_domain=None):
+    def _build_cache(cls, allowed_audience_fields, au_domain=None):
 
         if au_domain is None or au_domain == '_global':
             au_domains = list(set(['_global', *cls.audience_domains]))
         else:
             au_domains = [au_domain]
         for d in au_domains:
-            audience_queries, raw_data = cls.get_queries_from_db(au_domain=d)
+            audience_queries, raw_data = cls.get_queries_from_db(au_domain=d,
+                                                                 allowed_audience_fields=allowed_audience_fields)
             cls._queries_to_cache(au_domain=au_domain, audience_data=raw_data)
 
     @property
